@@ -45,11 +45,11 @@ class TestDescribe(object):
     def test_inherits(self):
 
         objects, relations, inherits = sadisplay \
-                .describe([model.User, model.Admin])
+                .describe([model.User, model.Admin, model.Manager])
 
         assert len(relations) == 0
-        assert len(objects) == 2
-        assert len(inherits) == 1
+        assert len(objects) == 3
+        assert len(inherits) == 2
         assert_equal(
             objects[1],
             {
@@ -129,3 +129,19 @@ class TestDescribe(object):
                 'methods': [],
             }
         )
+
+        objects, relations, inherits = sadisplay \
+                .describe([model.books])
+
+        assert len(objects) == 1
+        assert_equal(
+            objects[0],
+            {
+                'name': model.books.name,
+                'cols': [('Integer', 'id'),
+                        ('Unicode', 'title'),
+                        ('Integer', 'user_id'), ],
+                'props': [],
+                'methods': [],
+            }
+        ) 
